% This program replicates Figure 6 in "Optimal Dynamic Capital Requirements
% and Implementable Capital Buffer Rules" by Matthew Canzoneri, Behzad
% Diba, Luca Guerrieri and Arsenii Mishin.
%
% The program produces Figure 6, corresponding to sensitivity analysis for
% the TFP shock.

%% set inputs for solution below
%  The program produces responses to the shocks selected below under
%  irfshock. Paths for all the endogenous variables in the model selected
%  are produced. VariableName_piecewise holds the piece-wise linear solution for
%  VariableName.  VariableName_linear holds the linear solution for
%  VariableName.

clear all

setpath_windows

global M_ oo_
global changes_names changes_vec

changes_names = char('');
changes_vec = [];


shockssequence = [-1];
irfshock = 'eps_a';
nperiods = 100;
maxiter = 1000;
                          
modnam = 'model_calibration';

all_changes_vec = [0.04:0.01:.20];

nchanges = length(all_changes_vec);

changes_names = char('taup','gammap_increment','phip_i');
changes_vec = [nan, 0.001,100];  % taup is assigned in the loop below

for this_change = 1:nchanges

changes_vec(1) = all_changes_vec(this_change);


[zdatalinear, zdatass, oobase_, Mbase_ ] = ...
     solve_no_constraint(modnam,...
     shockssequence,irfshock,nperiods);
    
    ytot_var_pos= strmatch('ytot',Mbase_.endo_names,'exact');
    max_ytot(this_change) = max(abs(zdatalinear(:,ytot_var_pos)))/zdatass(ytot_var_pos)*100;
    % normalize for a 1 percent drop in output (given linearity);
    gamma_var_pos = strmatch('gamma_var',Mbase_.endo_names,'exact');
    %gamma_var_max(this_change) = max(zdatalinear(:,gamma_var_pos)/max_ytot*100);
    gamma_var_max(this_change) = max(zdatalinear(:,gamma_var_pos)*100);
    
end

changes_vec =[];
change_names = '';
[zdatalinear, zdatass, oobase_, Mbase_ ] = ...
     solve_no_constraint(modnam,...
     shockssequence,irfshock,nperiods);

 %plot(zdatalinear(:,strmatch('ytot',Mbase_.endo_names,'exact'))*100)
 
max_ytot_baseline = max(abs(zdatalinear(:,ytot_var_pos)))/zdatass(ytot_var_pos)*100;
gamma_baseline = max(zdatalinear(:,gamma_var_pos)*100);
taup = Mbase_.params(strmatch('taup',Mbase_.param_names));

%add taup to grid of values
interim = [taup all_changes_vec];

[sorted_interim, sort_order] = sort(interim);
interim_values = [gamma_baseline, gamma_var_max];
interim_values_ytot= [max_ytot_baseline, max_ytot];
sorted_interim_values = interim_values(sort_order);
sorted_interim_values_ytot = interim_values_ytot(sort_order);

figure
subplot(2,2,1)
plot(sorted_interim,sorted_interim_values,'LineWidth',1.5); hold on
xlabel('Standard deviation of idiosyncratic returns for risky projects')
title('Max. \Delta in capital requirements, \tau sensitivity')
ylabel('Perc. Pt., dev. from steady state')
ylim([0 1])
plot(taup,gamma_baseline,'o')
% b=regress(gamma_var_max', [0*all_changes_vec'+1 all_changes_vec'])
% hold on
% plot(all_changes_vec,[0*all_changes_vec'+1 all_changes_vec']*b,'r--')
% title('Sensitivity with respect to \tau')
xlim([min(sorted_interim) max(sorted_interim)])

subplot(2,2,3) 
plot(sorted_interim,sorted_interim_values_ytot,'LineWidth',1.5); hold on
ylabel('% dev. from steady state')
title('Max. \Delta in output, \tau sensitivity')
xlabel('Standard deviation of idiosyncratic returns for risky projects')

ylim([0 2])
xlim([min(sorted_interim) max(sorted_interim)])




%% now do it again for xip
all_changes_vec = [0.00005:0.000005:0.00009,  0.0001:0.0005:0.01];

nchanges = length(all_changes_vec);

changes_names = char('xip','gammap_increment','phip_i');
changes_vec = [nan, 0.001,100];  % taup is assigned in the loop below

for this_change = 1:nchanges

changes_vec(1) = all_changes_vec(this_change);


[zdatalinear, zdatass, oobase_, Mbase_ ] = ...
     solve_no_constraint(modnam,...
     shockssequence,irfshock,nperiods);
 
 
    gamma_var_pos = strmatch('gamma_var',Mbase_.endo_names,'exact');
    ytot_var_pos= strmatch('ytot',Mbase_.endo_names,'exact');
    max_ytot(this_change) = max(abs(zdatalinear(:,ytot_var_pos)))/zdatass(ytot_var_pos)*100;
    % normalize for a 1 percent drop in output (given linearity);
    %gamma_var_max(this_change) = max(zdatalinear(:,gamma_var_pos)/max_ytot*100);
    gamma_var_max(this_change) = max(zdatalinear(:,gamma_var_pos)*100);
    
end

changes_vec =[];
change_names = '';
[zdatalinear, zdatass, oobase_, Mbase_ ] = ...
     solve_no_constraint(modnam,...
     shockssequence,irfshock,nperiods);
 
max_ytot_baseline = max(abs(zdatalinear(:,ytot_var_pos)))/zdatass(ytot_var_pos)*100;
gamma_baseline = max(zdatalinear(:,gamma_var_pos)*100);
xip = Mbase_.params(strmatch('xip',Mbase_.param_names));

interim = [xip all_changes_vec];
interim_values = [gamma_baseline gamma_var_max];
[sorted_interim sort_order] = sort(interim);
interim_values_ytot= [max_ytot_baseline, max_ytot];
sorted_interim_values = interim_values(sort_order);
sorted_interim_values_ytot = interim_values_ytot(sort_order);


subplot(2,2,2)
% splined_all_changes_vec = [0.00005:0.000001:0.00009, 0.0001:0.0005:0.01];
% splined_gamma_var_max = spline(all_changes_vec,gamma_var_max,splined_all_changes_vec);
plot(100*sorted_interim,sorted_interim_values,'LineWidth',1.5); hold on
title('Max. \Delta in capital requirements, \xi sensitivity')
ylabel('Perc. Pt., dev. from steady state')
plot(100*xip,gamma_baseline,'o')

ylim([0 1])
xlabel('Average penalty on returns to risky projects, perc. pt.')


subplot(2,2,4) 
plot(sorted_interim*100,sorted_interim_values_ytot,'LineWidth',1.5); hold on
ylabel('% dev. from steady state')
title('Max. \Delta in output, \xi sensitivity')
xlabel('Standard deviation of idiosyncratic returns for risky projects')
ylim([0 2])