%%

clear all

global changes_names changes_vec

setpath_windows

% remember to 
% set to 0 to exclude the volatility shocks --- choose when using with
% call_table_8.m 
% set to 1 for the model that includes volatility shocks --- choose when
% using with call_table_9.m

tau_switch = 0;



if tau_switch
    irf_shock = char('eps_a','eps_isp','eps_tau');
else
    irf_shock = char('eps_a','eps_isp');
end

changes_names = char('sigma_eps_a','sigma_eps_isp',...
                     'rhop_a','rho_isp','phip_i','kappap');

                 
load my_estimates distance_param;
    
changes_vec = distance_param;

model_safe_paramfile
modnam = 'model_calibration';



nperiods = 1000;

randn('seed',1); 
nshocks = size(irf_shock,1);

shockssequence = randn(nperiods,nshocks);

[zdatalinear, zdatass, oobase_, Mbase_ ] = ...
     solve_no_constraint(modnam,shockssequence,irf_shock,nperiods);
 

statevar_pos = (Mbase_.nstatic +1):(Mbase_.endo_nbr-Mbase_.nfwrd);


reordered_variables = Mbase_.endo_names(oobase_.dr.order_var,:);

state_variables = deblank(reordered_variables(statevar_pos,:));



% exclude gamma_var from list
gamma_var_pos = strmatch('gamma_var',deblank(state_variables),'exact');
kap_quality_pos = strmatch('kap_quality',deblank(state_variables),'exact');
a_pos = strmatch('a',deblank(state_variables),'exact');
isp_pos = strmatch('isp',deblank(state_variables),'exact');

state_variables([gamma_var_pos kap_quality_pos  isp_pos],:) = [];
n_statevars = size(state_variables,1);


prefix1 = 'f0_'; 

for this_var = 1:Mbase_.endo_nbr
    eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'_data=zdatalinear(:,this_var);'])
    eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'=zdatass(this_var);'])
 
    
end 

yreg  = f0_gamma_var_data;

for this_var_pos =1:n_statevars
    this_var = state_variables(this_var_pos,:);
    
  
    xreg = eval(['f0_',deblank(this_var),'_data']);
    xreg = [0*xreg+1 xreg];
    
    [B,BINT,R,RINT,STATS] = regress(yreg,xreg);
    rsquared(this_var_pos) = STATS(1);
    
end





strcat(state_variables,' ',num2str(rsquared'))

statevar_pos_short = statevar_pos;
statevar_pos_short([gamma_var_pos kap_quality_pos a_pos isp_pos])=[];

n_vars = 2;
two_state_variables = combnk(statevar_pos_short,n_vars);
n_combinations=size(two_state_variables,1);

for combination_indx = 1:n_combinations
    xreg = [];
    
    message = [];
    for var_indx = 1:n_vars
    this_var = reordered_variables(two_state_variables(combination_indx,var_indx),:);
   
    xreg = [xreg eval(['f0_',deblank(this_var),'_data'])];
    message = [message,this_var,' '];
    end
    xreg = [0*xreg(:,1)+1 xreg];
    
    
    [B,BINT,R,RINT,STATS] = regress(yreg,xreg);
    rsquared(this_var_pos) = STATS(1);
    message = [message,' have an R2 of ',num2str(STATS(1)),' with coefs ',num2str(B')];
    display(message);
end


% Line 1 of table
xreg = eval(['f0_q_data']);
xreg = [0*xreg+1 xreg];
[B,BINT,R,RINT,STATS] = regress(yreg,xreg);
display('investment price')
B
STATS(1)


% Line 2 of table
xreg = f0_banking_spread_data;
xreg = [0*xreg+1 xreg  ];
[B,BINT,R,RINT,STATS] = regress(yreg,xreg);
display('expected banking spread')
B
STATS(1)

% line 3 of table
xreg = f0_ytot_data;
xreg = [0*xreg+1 xreg  ];
[B,BINT,R,RINT,STATS] = regress(yreg,xreg);
display('aggregate output')
B
STATS(1)


xreg = eval(['f0_ltot2ytot_data']);
xreg = [0*xreg+1 xreg];
[B,BINT,R,RINT,STATS] = regress(yreg,xreg);
display('Credit 2 GDP')
B
STATS(1)

xreg = eval(['f0_r_l_lead_data']);
xreg = [0*xreg+1 xreg f0_r_d_data ];
[B,BINT,R,RINT,STATS] = regress(yreg,xreg);
display('safe loan rate and deposit rate')
B
STATS(1)




eps_a = shockssequence(:,1);

eps_isp = shockssequence(:,2);

if tau_switch
eps_tau = shockssequence(:,3);
end       

if tau_switch
xreg = eps_a;
xreg = [0*xreg eps_a f0_a_data eps_isp f0_isp_data eps_tau f0_tau_var_data f0_r_l_lead_data f0_r_d_data];
[B,BINT,R,RINT,STATS] = regress(yreg,xreg);
display('all terms')
B
STATS(1)
else
xreg = eps_a;
xreg = [0*xreg+1 eps_a f0_a_data eps_isp f0_isp_data f0_r_l_lead_data f0_r_d_data ];
[B,BINT,R,RINT,STATS] = regress(yreg,xreg);
display('all terms')
B
STATS(1)    
end  


gamma_var_lag_data = [0;
                 f0_gamma_var_data(1:end-1)];
             
if tau_switch
xreg = eps_a;
xreg = [0*xreg+1 eps_a f0_a_data eps_isp f0_isp_data eps_tau f0_tau_var_data gamma_var_lag_data];
[B,BINT,R,RINT,STATS] = regress(yreg,xreg);
display('all terms')
B
STATS(1)
else
  xreg = eps_a;
xreg = [0*xreg+1 eps_a f0_a_data eps_isp f0_isp_data gamma_var_lag_data];
[B,BINT,R,RINT,STATS] = regress(yreg,xreg);
display('all terms')
B
STATS(1)  
end



% xreg = eps_a;
% xreg = [0*xreg+1  f0_r_l_data f0_r_d_data f0_q_data];
% [B,BINT,R,RINT,STATS] = regress(yreg,xreg);
% display('no shocks terms')
% B
% STATS(1)

%%
% combinations = nchoosek(1:n_statevars,2);
% 
% 
% n_combinations = size(combinations,1);
% 
% for this_combination=1:n_combinations 
%     
%     xreg = eval(['f0_',deblank(state_variables(combinations(this_combination,1),:)),'_data']);
%     xreg = [xreg eval(['f0_',deblank(state_variables(combinations(this_combination,2))),'_data'])];
%     xreg = [0*xreg(:,1)+1 xreg];
%     
%     [B,BINT,R,RINT,STATS] = regress(yreg,xreg);
%     rsquared(this_combination) = STATS(1);
% end


